@@ -4,13 +4,14 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '2.07';
+our $VERSION = '2.08';
 our %EXPORT_TAGS = (
     all => [ qw( ll_to_grid grid_to_ll
                  shift_ll_into_WGS84 shift_ll_from_WGS84
                  parse_ISO_ll format_ll_trad format_ll_ISO
                  parse_grid parse_trad_grid parse_GPS_grid parse_landranger_grid
                  format_grid_trad format_grid_GPS format_grid_landranger
+                 random_grid
            )]
     );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{all} } );
@@ -184,8 +185,6 @@ sub _compute_big_m {
            );
 }
 
-
-
 my %BIG_OFF = (
               G => { E => -1, N => 2 },
               H => { E =>  0, N => 2 },
@@ -442,6 +441,21 @@ my %LR = (
     204 => [ 172_000,    14_000 ] ,
 );
 
+sub random_grid {
+    my @preferred_sheets = @_;
+    my @sheets;
+    if (@preferred_sheets > 0) {
+        @sheets = map { $_ if exists $LR{$_} } @preferred_sheets;
+    }
+    else {
+        @sheets = keys %LR;
+    }
+    my $map = $sheets[ int rand $#sheets ];
+    my $easting = $LR{$map}[0] + int(rand LR_SHEET_SIZE);
+    my $northing = $LR{$map}[1] + int(rand LR_SHEET_SIZE);
+    return ($easting, $northing);
+}
+
 sub format_grid_trad {
     my $e = shift;
     my $n = shift;
@@ -693,7 +707,6 @@ sub parse_ISO_ll {
 #        * The integer part and the fraction part of altitude are both variable-length.
 #
 
-
 sub format_ll_trad {
     my ($lat, $lon) = @_;
     my ($lad, $lam, $las, $is_north) = _dms($lat); my $lah = $is_north ? 'N' : 'S';
@@ -911,7 +924,8 @@ Note that the OSGB (and therefore this module) does not cover the whole of the
 British Isles, nor even the whole of the UK, in particular it covers neither
 the Channel Islands nor Northern Ireland.  The coverage that is included is
 essentially the same as the coverage provided by the OSGB "Landranger" 1:50000
-series maps.
+series maps.  The coverage of the OSTN02 data set is slightly smaller, as 
+the OS do not define the model for any points more than about 2km off shore.
 
 =head1 VERSION
 
@@ -960,6 +974,8 @@ module:
     parse_GPS_grid              format_grid_GPS
     parse_landranger_grid       format_grid_landranger
 
+    random_grid
+
     parse_ISO_ll                format_ll_trad
                                 format_ll_ISO
 
@@ -1233,9 +1249,20 @@ C<grid_to_ll()>.  Like so:
   ($lat, $lon) = grid_to_ll($e, $n);
   ($lat, $lon, $alt) = shift_ll_into_WGS84($lat, $lon, $alt);
 
-This routine provide a fast approximation; for a slower, more accurate
+This routine provide a fast approximation; for a more accurate
 approximation use the companion L<Geo::Coordinates::OSTN02> modules.
 
+=item random_grid([sheet1, sheet2, ...])
+
+Takes an optional list of Landranger map numbers (1..204), and returns a random
+easting and northing for some place covered by one of the maps.  There's no
+guarantee that the point will not be in the sea, but it will be on one of the
+maps. If you omit the list of sheets, then one of the 204 will be picked at
+random.  If the list includes sheet numbers that are not in the range 1..204
+they will be (silently) ignored.  The easting and northing are returns as
+meters from Newlyn, so that they are suitable for input to any of the
+c<format_grid> routines.
+
 =back
 
 
@@ -1465,6 +1492,10 @@ C<grid_to_ll()> with the WGS84 parameter to get WGS84 lat/long coordinates.
    ($x, $y, $z) = OSGB36_to_ETRS89($e, $n, $elevation);
    ($lat, $lon) = grid_to_ll($x, $y, 'WGS84');
 
+The coverage of OSTN02 is limited to about 2km beyond the shore line, of the
+British mainland.  This means that some parts of the Landranger map series are
+outside the coverage, but only where they extend far out to sea.
+
 
 =head1 EXAMPLES
 
@@ -1522,7 +1553,9 @@ neither C<$a==$a1> nor C<$b==$b1>. However C<abs($a-$a1)> and C<abs($b-$b1)>
 should be less than C<0.00001> which will give you accuracy to within a
 metre. In the middle of the grid 0.00001 degrees is approximately 1 metre.
 Note that the error increases the further away you are from the
-central meridian of the grid system.
+point of false origin.  You'll notice it most if you are working with grid 
+references from the Shetland Islands, where the round trip error may be as much as 10 metres.
+If you need more accurate conversions use the OSTN02 routines.
 
 The C<format_grid_landranger()> does not take account of inset areas on the
 sheets.  So if you feed it a reference for the Scilly Isles, it will tell you
@@ -1533,6 +1566,13 @@ be added as extra sheets with names like "Sheet 2003 Inset 1" with their own
 reference points and special sheet sizes.  Collecting the data is another
 matter.
 
+The coveraage of the OSGB routines is more or less the same as the Landranger
+series of maps.  The coverage of the OSTN02 routines is slightly smaller, as
+the model is not defined by the OS for points beyond about 2km from the shore.
+This is not a problem if you are working with reference from onland but might
+surprise you if you are working with the coordinates (for example) of the
+corners of any Landranger sheet on the coast.
+
 Not enough testing has been done.  I am always grateful for the feedback I
 get from users, but especially for problem reports that help me to make this
 a better module.
